---
title: Widgets
---

### Widgets

Dashboard widgets are Stream entries that are associated with an `extension`. The extensions along with configuration using the [Configuration module](/documentation/documentation/configuration-module).


#### Widget Fields

Below is a list of `fields` in the `widgets` stream. Fields are accessed as attributes:

    $widget->title;

Same goes for decorated instances in Twig:

    {{ widget.title }}

###### Fields

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Type</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

title

</td>

<td>

text

</td>

<td>

The title.

</td>

</tr>

<tr>

<td>

description

</td>

<td>

textarea

</td>

<td>

The description.

</td>

</tr>

<tr>

<td>

extension

</td>

<td>

addon

</td>

<td>

The widget extension.

</td>

</tr>

<tr>

<td>

column

</td>

<td>

integer

</td>

<td>

The column placement.

</td>

</tr>

<tr>

<td>

pinned

</td>

<td>

boolean

</td>

<td>

The pinned state.

</td>

</tr>

<tr>

<td>

dashboard

</td>

<td>

relationship

</td>

<td>

The related dashboard.

</td>

</tr>

<tr>

<td>

allowed_roles

</td>

<td>

multiple

</td>

<td>

The roles allowed to view the widget.

</td>

</tr>

</tbody>

</table>


#### Widget Interface

This section will go over the `\Anomaly\DashboardModule\Widget\Contract\WidgetInterface` class.


##### WidgetInterface::output()

The `output` method returns the complete widget output.

###### Returns: `string`

###### Example

    $widget->output();

###### Twig

    {{ widget.output()|raw }}


##### WidgetInterface::addData()

The `addData` method adds data to the widget's data for access later in processing and output.

###### Returns: `\Anomaly\Streams\Platform\Entry\Contract\EntryInterface`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$key

</td>

<td>

true

</td>

<td>

string

</td>

<td>

none

</td>

<td>

The data key.

</td>

</tr>

<tr>

<td>

$data

</td>

<td>

true

</td>

<td>

mixed

</td>

<td>

none

</td>

<td>

The data.

</td>

</tr>

</tbody>

</table>

###### Example

    $widget->addData('example', 'http://pyrocms.com');


##### WidgetInterface::getData()

The `getData` method returns the widget's data collection.

###### Returns: `\Anomaly\DashboardModule\Widget\WidgetData`

###### Example

    $widget->getData()->get('example');

###### Twig

    {{ widget.getData().get('example') }}


##### WidgetInterface::setContent()

The `setContent` method sets the interior content for the widget wrapper view.

###### Returns: `\Anomaly\DashboardModule\Widget\Contract\WidgetInterface`

###### Arguments

<table class="table table-bordered table-striped">

<thead>

<tr>

<th>Key</th>

<th>Required</th>

<th>Type</th>

<th>Default</th>

<th>Description</th>

</tr>

</thead>

<tbody>

<tr>

<td>

$content

</td>

<td>

true

</td>

<td>

string

</td>

<td>

none

</td>

<td>

The rendered content.

</td>

</tr>

</tbody>

</table>

###### Example

    $widget->setContent($html);


##### WidgetInterface::getContent()

The `getContent` method gets the interior content for the widget wrapper view.

###### Returns: `string`

###### Example

    $widget->getContent();

###### Twig

    {{ widget.getContent()|raw }}

